==> qiho-center-biz-1.2.4-sources.jar: com/qiho/center/biz/service/impl/order/AnticheateServiceImpl.java <==
/**
 * Project Name:qiho-center-biz
 * File Name:AnticheateServiceImpl.java
 * Package Name:com.qiho.center.biz.service.impl.order
 * Date:2017年6月6日下午1:43:44
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package com.qiho.center.biz.service.impl.order;

import java.util.List;

import com.qiho.center.common.constant.DsConstants;
import com.qiho.center.common.entity.order.QihoAnticheateEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.qiho.center.api.dto.AnticheateDto;
import com.qiho.center.biz.service.order.AnticheateService;
import com.qiho.center.common.dao.QihoAnticheateDAO;
import org.springframework.transaction.annotation.Transactional;


/**
 * ClassName:AnticheateServiceImpl <br/>
 * Date:     2017年6月6日 下午1:43:44 <br/>
 * @author   zhanglihui
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service
public class AnticheateServiceImpl implements AnticheateService {
    @Autowired
    private QihoAnticheateDAO qihoAnticheateDAO;
    
    @Override
    public AnticheateDto findByOrderId(String orderId) {
        List<String>  rules = qihoAnticheateDAO.findByOrderId(orderId);
        AnticheateDto anticheateDto = new AnticheateDto();
        anticheateDto.setOrderId(orderId);
        anticheateDto.setRules(rules);
        return anticheateDto;
    }

    @Override
    @Transactional(DsConstants.DATABASE_QIHO)
    public void insert(QihoAnticheateEntity qihoAnticheateEntity) {
        qihoAnticheateDAO.insert(qihoAnticheateEntity);
    }

}

==> qiho-center-biz-2.3.2-sources.jar: com/qiho/center/biz/service/impl/order/AnticheateServiceImpl.java <==
/**
 * Project Name:qiho-center-biz
 * File Name:AnticheateServiceImpl.java
 * Package Name:com.qiho.center.biz.service.impl.order
 * Date:2017年6月6日下午1:43:44
 * Copyright (c) 2017, duiba.com.cn All Rights Reserved.
 *
*/

package com.qiho.center.biz.service.impl.order;

import java.util.List;
import java.util.stream.Collectors;

import com.google.common.collect.Lists;
import com.qiho.center.common.constant.DsConstants;
import com.qiho.center.common.entity.order.QihoAnticheateEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.qiho.center.api.dto.AnticheateDto;
import com.qiho.center.biz.service.order.AnticheateService;
import com.qiho.center.common.dao.QihoAnticheateDAO;
import org.springframework.transaction.annotation.Transactional;


/**
 * ClassName:AnticheateServiceImpl <br/>
 * Date:     2017年6月6日 下午1:43:44 <br/>
 * @author   zhanglihui
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
@Service
public class AnticheateServiceImpl implements AnticheateService {
    @Autowired
    private QihoAnticheateDAO qihoAnticheateDAO;
    
    @Override
    public AnticheateDto findByOrderId(String orderId) {
        List<String>  rules = qihoAnticheateDAO.findByOrderId(orderId);
        AnticheateDto anticheateDto = new AnticheateDto();
        anticheateDto.setOrderId(orderId);
        anticheateDto.setRules(rules);
        return anticheateDto;
    }

    @Override
    @Transactional(DsConstants.DATABASE_QIHO)
    public void insert(QihoAnticheateEntity qihoAnticheateEntity) {
        qihoAnticheateDAO.insert(qihoAnticheateEntity);
    }

    @Override
    public List<AnticheateDto> findByOrderIds(List<String> orderIds) {
        List<AnticheateDto> anticheateDtos = Lists.newArrayList();
        List<QihoAnticheateEntity> anticheateEntities = qihoAnticheateDAO.findByOrderIds(orderIds);
        for (String orderId : orderIds){
            AnticheateDto anticheateDto = new AnticheateDto();
            anticheateDto.setOrderId(orderId);
            List<String> rules = anticheateEntities.stream().filter(e -> orderId.equals(e.getOrderId()))
                                                            .map(QihoAnticheateEntity::<String>getRule).collect(Collectors.toList());
            anticheateDto.setRules(rules);
            anticheateDtos.add(anticheateDto);
        }
        return anticheateDtos;
    }

}
